@@ -1,5 +1,6 @@
 from .utils.json_map import JsonMap
 from .utils.base_model import BaseModel
+from .utils.sentinel import SENTINEL
 
 
 @JsonMap({})
@@ -10,12 +11,12 @@ class AddEnvelopeDocumentRequest(BaseModel):
     :type file: bytes, optional
     """
 
-    def __init__(self, file: bytes = None, **kwargs):
+    def __init__(self, file: bytes = SENTINEL, **kwargs):
         """AddEnvelopeDocumentRequest
 
         :param file: File to upload in binary format, defaults to None
         :type file: bytes, optional
         """
-        if file is not None:
+        if file is not SENTINEL:
             self.file = file
         self._kwargs = kwargs
