@@ -1,5 +1,6 @@
 from .utils.json_map import JsonMap
 from .utils.base_model import BaseModel
+from .utils.sentinel import SENTINEL
 
 
 @JsonMap({})
@@ -14,7 +15,9 @@ class CreateEnvelopeFromTemplateRequest(BaseModel):
     :type sandbox: bool, optional
     """
 
-    def __init__(self, name: str, comment: str = None, sandbox: bool = None, **kwargs):
+    def __init__(
+        self, name: str, comment: str = SENTINEL, sandbox: bool = SENTINEL, **kwargs
+    ):
         """CreateEnvelopeFromTemplateRequest
 
         :param name: Name of the envelope
@@ -24,9 +27,15 @@ class CreateEnvelopeFromTemplateRequest(BaseModel):
         :param sandbox: Whether the envelope is created in sandbox mode, defaults to None
         :type sandbox: bool, optional
         """
-        self.name = name
-        if comment is not None:
+        self.name = self._define_str(
+            "name",
+            name,
+            pattern="^[a-zA-Z0-9][a-zA-Z0-9 ]*[a-zA-Z0-9]$",
+            min_length=2,
+            max_length=256,
+        )
+        if comment is not SENTINEL:
             self.comment = comment
-        if sandbox is not None:
+        if sandbox is not SENTINEL:
             self.sandbox = sandbox
         self._kwargs = kwargs
