@@ -1,5 +1,6 @@
 from .utils.json_map import JsonMap
 from .utils.base_model import BaseModel
+from .utils.sentinel import SENTINEL
 
 
 @JsonMap({})
@@ -12,7 +13,7 @@ class DynamicField(BaseModel):
     :type value: str, optional
     """
 
-    def __init__(self, name: str = None, value: str = None):
+    def __init__(self, name: str = SENTINEL, value: str = SENTINEL, **kwargs):
         """DynamicField
 
         :param name: Name of the dynamic field, defaults to None
@@ -20,7 +21,8 @@ class DynamicField(BaseModel):
         :param value: Value of the dynamic field, defaults to None
         :type value: str, optional
         """
-        if name is not None:
+        if name is not SENTINEL:
             self.name = name
-        if value is not None:
+        if value is not SENTINEL:
             self.value = value
+        self._kwargs = kwargs
