@@ -2,6 +2,7 @@ from __future__ import annotations
 from typing import List
 from .utils.json_map import JsonMap
 from .utils.base_model import BaseModel
+from .utils.sentinel import SENTINEL
 from .template import Template
 
 
@@ -19,9 +20,9 @@ class ListTemplatesResponse(BaseModel):
 
     def __init__(
         self,
-        has_next_page: bool = None,
-        has_previous_page: bool = None,
-        templates: List[Template] = None,
+        has_next_page: bool = SENTINEL,
+        has_previous_page: bool = SENTINEL,
+        templates: List[Template] = SENTINEL,
         **kwargs,
     ):
         """ListTemplatesResponse
@@ -33,10 +34,10 @@ class ListTemplatesResponse(BaseModel):
         :param templates: templates, defaults to None
         :type templates: List[Template], optional
         """
-        if has_next_page is not None:
+        if has_next_page is not SENTINEL:
             self.has_next_page = has_next_page
-        if has_previous_page is not None:
+        if has_previous_page is not SENTINEL:
             self.has_previous_page = has_previous_page
-        if templates is not None:
+        if templates is not SENTINEL:
             self.templates = self._define_list(templates, Template)
         self._kwargs = kwargs
