@@ -12,12 +12,15 @@ class WebhookEvent(Enum):
     :vartype ENVELOPEVOIDED: str
     :cvar ENVELOPECOMPLETED: "ENVELOPE_COMPLETED"
     :vartype ENVELOPECOMPLETED: str
+    :cvar ENVELOPEAUDITTRAIL: "ENVELOPE_AUDIT_TRAIL"
+    :vartype ENVELOPEAUDITTRAIL: str
     """
 
     ENVELOPEEXPIRED = "ENVELOPE_EXPIRED"
     ENVELOPEDECLINED = "ENVELOPE_DECLINED"
     ENVELOPEVOIDED = "ENVELOPE_VOIDED"
     ENVELOPECOMPLETED = "ENVELOPE_COMPLETED"
+    ENVELOPEAUDITTRAIL = "ENVELOPE_AUDIT_TRAIL"
 
     def list():
         """Lists all category values.
