@@ -2,6 +2,8 @@ from typing import List
 from .utils.validator import Validator
 from .utils.base_service import BaseService
 from ..net.transport.serializer import Serializer
+from ..net.environment.environment import Environment
+from ..models.utils.sentinel import SENTINEL
 from ..models.utils.cast_models import cast_models
 from ..models import (
     AddAnnotationRequest,
@@ -58,7 +60,10 @@ class SignplusService(BaseService):
         Validator(CreateEnvelopeRequest).validate(request_body)
 
         serialized_request = (
-            Serializer(f"{self.base_url}/envelope", self.get_default_headers())
+            Serializer(
+                f"{self.base_url or Environment.DEFAULT.url}/envelope",
+                [self.get_access_token()],
+            )
             .serialize()
             .set_method("POST")
             .set_body(request_body)
@@ -89,8 +94,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/from_template/{{template_id}}",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/from_template/{{template_id}}",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -119,7 +124,10 @@ class SignplusService(BaseService):
         Validator(ListEnvelopesRequest).is_optional().validate(request_body)
 
         serialized_request = (
-            Serializer(f"{self.base_url}/envelopes", self.get_default_headers())
+            Serializer(
+                f"{self.base_url or Environment.DEFAULT.url}/envelopes",
+                [self.get_access_token()],
+            )
             .serialize()
             .set_method("POST")
             .set_body(request_body)
@@ -145,7 +153,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}", self.get_default_headers()
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -170,7 +179,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}", self.get_default_headers()
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -179,6 +189,68 @@ class SignplusService(BaseService):
 
         self.send_request(serialized_request)
 
+    @cast_models
+    def download_envelope_signed_documents(
+        self, envelope_id: str, certificate_of_completion: bool = SENTINEL
+    ) -> any:
+        """Download signed documents for an envelope
+
+        :param envelope_id: ID of the envelope
+        :type envelope_id: str
+        :param certificate_of_completion: Whether to include the certificate of completion in the downloaded file, defaults to None
+        :type certificate_of_completion: bool, optional
+        ...
+        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
+        ...
+        :return: The parsed response data.
+        :rtype: any
+        """
+
+        Validator(str).validate(envelope_id)
+        Validator(bool).is_optional().validate(certificate_of_completion)
+
+        serialized_request = (
+            Serializer(
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/signed_documents",
+                [self.get_access_token()],
+            )
+            .add_path("envelope_id", envelope_id)
+            .add_query("certificate_of_completion", certificate_of_completion)
+            .serialize()
+            .set_method("GET")
+        )
+
+        response, _, _ = self.send_request(serialized_request)
+        return response
+
+    @cast_models
+    def download_envelope_certificate(self, envelope_id: str) -> any:
+        """Download certificate of completion for an envelope
+
+        :param envelope_id: ID of the envelope
+        :type envelope_id: str
+        ...
+        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
+        ...
+        :return: The parsed response data.
+        :rtype: any
+        """
+
+        Validator(str).validate(envelope_id)
+
+        serialized_request = (
+            Serializer(
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/certificate",
+                [self.get_access_token()],
+            )
+            .add_path("envelope_id", envelope_id)
+            .serialize()
+            .set_method("GET")
+        )
+
+        response, _, _ = self.send_request(serialized_request)
+        return response
+
     @cast_models
     def get_envelope_document(self, envelope_id: str, document_id: str) -> Document:
         """Get envelope document
@@ -199,8 +271,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/document/{{document_id}}",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/document/{{document_id}}",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .add_path("document_id", document_id)
@@ -228,8 +300,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/documents",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/documents",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -261,8 +333,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/document",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/document",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -295,8 +367,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/dynamic_fields",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/dynamic_fields",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -329,8 +401,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/signing_steps",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/signing_steps",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -358,8 +430,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/send",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/send",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -386,8 +458,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/duplicate",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/duplicate",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -414,8 +486,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/void",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/void",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -447,8 +519,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/rename",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/rename",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -481,8 +553,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/set_comment",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/set_comment",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -515,8 +587,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/set_notification",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/set_notification",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -549,8 +621,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/set_expiration_date",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/set_expiration_date",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -583,8 +655,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/set_legality_level",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/set_legality_level",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -612,8 +684,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/annotations",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/annotations",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -645,8 +717,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/annotations/{{document_id}}",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/annotations/{{document_id}}",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .add_path("document_id", document_id)
@@ -679,8 +751,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/annotation",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/annotation",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .serialize()
@@ -709,8 +781,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/envelope/{{envelope_id}}/annotation/{{annotation_id}}",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/envelope/{{envelope_id}}/annotation/{{annotation_id}}",
+                [self.get_access_token()],
             )
             .add_path("envelope_id", envelope_id)
             .add_path("annotation_id", annotation_id)
@@ -736,7 +808,10 @@ class SignplusService(BaseService):
         Validator(CreateTemplateRequest).validate(request_body)
 
         serialized_request = (
-            Serializer(f"{self.base_url}/template", self.get_default_headers())
+            Serializer(
+                f"{self.base_url or Environment.DEFAULT.url}/template",
+                [self.get_access_token()],
+            )
             .serialize()
             .set_method("POST")
             .set_body(request_body)
@@ -763,7 +838,10 @@ class SignplusService(BaseService):
         Validator(ListTemplatesRequest).is_optional().validate(request_body)
 
         serialized_request = (
-            Serializer(f"{self.base_url}/templates", self.get_default_headers())
+            Serializer(
+                f"{self.base_url or Environment.DEFAULT.url}/templates",
+                [self.get_access_token()],
+            )
             .serialize()
             .set_method("POST")
             .set_body(request_body)
@@ -789,7 +867,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}", self.get_default_headers()
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -814,7 +893,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}", self.get_default_headers()
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -840,8 +920,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/duplicate",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/duplicate",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -873,8 +953,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/document",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/document",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -905,8 +985,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/document/{{document_id}}",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/document/{{document_id}}",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .add_path("document_id", document_id)
@@ -934,8 +1014,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/documents",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/documents",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -967,8 +1047,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/signing_steps",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/signing_steps",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -1001,8 +1081,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/rename",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/rename",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -1035,8 +1115,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/set_comment",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/set_comment",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -1069,8 +1149,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/set_notification",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/set_notification",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -1100,8 +1180,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/annotations",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/annotations",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -1133,8 +1213,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/annotations/{{document_id}}",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/annotations/{{document_id}}",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .add_path("document_id", document_id)
@@ -1167,8 +1247,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/annotation",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/annotation",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .serialize()
@@ -1197,8 +1277,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/template/{{template_id}}/annotation/{{annotation_id}}",
-                self.get_default_headers(),
+                f"{self.base_url or Environment.DEFAULT.url}/template/{{template_id}}/annotation/{{annotation_id}}",
+                [self.get_access_token()],
             )
             .add_path("template_id", template_id)
             .add_path("annotation_id", annotation_id)
@@ -1224,7 +1304,10 @@ class SignplusService(BaseService):
         Validator(CreateWebhookRequest).validate(request_body)
 
         serialized_request = (
-            Serializer(f"{self.base_url}/webhook", self.get_default_headers())
+            Serializer(
+                f"{self.base_url or Environment.DEFAULT.url}/webhook",
+                [self.get_access_token()],
+            )
             .serialize()
             .set_method("POST")
             .set_body(request_body)
@@ -1251,7 +1334,10 @@ class SignplusService(BaseService):
         Validator(ListWebhooksRequest).is_optional().validate(request_body)
 
         serialized_request = (
-            Serializer(f"{self.base_url}/webhooks", self.get_default_headers())
+            Serializer(
+                f"{self.base_url or Environment.DEFAULT.url}/webhooks",
+                [self.get_access_token()],
+            )
             .serialize()
             .set_method("POST")
             .set_body(request_body)
@@ -1275,7 +1361,8 @@ class SignplusService(BaseService):
 
         serialized_request = (
             Serializer(
-                f"{self.base_url}/webhook/{{webhook_id}}", self.get_default_headers()
+                f"{self.base_url or Environment.DEFAULT.url}/webhook/{{webhook_id}}",
+                [self.get_access_token()],
             )
             .add_path("webhook_id", webhook_id)
             .serialize()
